Documentation
¶
Overview ¶
Package ddc defines the DDC services of BCE. The supported APIs are all defined in sub-package
ddc.go - the ddc APIs definition supported by the DDC service
Index ¶
- Constants
- type AccessDetailArgs
- type AccessDetailItem
- type Account
- type AccountPrivilege
- type AccountResult
- type AccountType
- type AuthType
- type BackupAccessDetail
- type BackupDetailResult
- type BackupPolicy
- type BatchInstanceIds
- type Billing
- type Binlog
- type BinlogDetailResult
- type BinlogListResult
- type BinlogModel
- type Client
- func (c *Client) BindSecurityGroups(args *SecurityGroupArgs) error
- func (c *Client) BinlogAccessDetail(args *AccessDetailArgs) (*BackupAccessDetail, error)
- func (c *Client) CreateAccount(instanceId string, args *CreateAccountArgs) error
- func (c *Client) CreateBackup(instanceId string) error
- func (c *Client) CreateDatabase(instanceId string, args *CreateDatabaseArgs) error
- func (cli *Client) CreateDeploySet(poolId string, args *CreateDeployRequest) error
- func (c *Client) CreateInstance(args *CreateInstanceArgs) (*CreateResult, error)
- func (c *Client) CreateRds(args *CreateRdsArgs) (*CreateResult, error)
- func (c *Client) CreateReadReplica(args *CreateReadReplicaArgs) (*CreateResult, error)
- func (c *Client) DeleteAccount(instanceId, accountName string) error
- func (c *Client) DeleteDatabase(instanceId, dbName string) error
- func (cli *Client) DeleteDeploySet(poolId string, deploySetId string) error
- func (c *Client) DeleteRds(instanceIds string) error
- func (c *Client) DeleteRecyclerInstances(instanceIds []string) error
- func (c *Client) GetAccount(instanceId, accountName string) (*Account, error)
- func (c *Client) GetBackupDetail(instanceId string, snapshotId string) (*BackupDetailResult, error)
- func (c *Client) GetBackupList(instanceId string) (*GetBackupListResult, error)
- func (c *Client) GetBinlogDetail(instanceId string, binlog string) (*BinlogDetailResult, error)
- func (c *Client) GetBinlogList(instanceId string, datetime string) (*BinlogListResult, error)
- func (c *Client) GetDatabase(instanceId, dbName string) (*Database, error)
- func (c *Client) GetDdcDetail(instanceId string) (*InstanceModelResult, error)
- func (cli *Client) GetDeploySet(poolId string, deploySetId string) (*DeploySet, error)
- func (c *Client) GetDetail(instanceId string) (*Instance, error)
- func (c *Client) GetDisk(instanceId string) (*Disk, error)
- func (c *Client) GetLogById(instanceId, logId string, args *GetLogArgs) (*LogDetail, error)
- func (c *Client) GetMaintainTime(instanceId string) (*MaintainTime, error)
- func (c *Client) GetSecurityIps(instanceId string) (*GetSecurityIpsResult, error)
- func (c *Client) GetZoneList() (*GetZoneListResult, error)
- func (c *Client) LazyDropCreateHardLink(instanceId, dbName, tableName string) error
- func (c *Client) LazyDropDeleteHardLink(instanceId, dbName, tableName string) error
- func (c *Client) ListAccount(instanceId string) (*ListAccountResult, error)
- func (c *Client) ListDatabase(instanceId string) (*ListDatabaseResult, error)
- func (cli *Client) ListDeploySets(poolId string, marker *Marker) (*ListDeploySetResult, error)
- func (c *Client) ListLogByInstanceId(instanceId string, args *ListLogArgs) (*[]Log, error)
- func (c *Client) ListParameters(instanceId string) (*ListParametersResult, error)
- func (cli *Client) ListPool(marker *Marker) (*ListPoolResult, error)
- func (c *Client) ListRds(marker *ListRdsArgs) (*ListRdsResult, error)
- func (c *Client) ListRecycleInstances(marker *Marker) (*RecyclerInstanceList, error)
- func (c *Client) ListRoGroup(instanceId string) (*ListRoGroupResult, error)
- func (c *Client) ListSecurityGroupByInstanceId(instanceId string) (*ListSecurityGroupResult, error)
- func (c *Client) ListSecurityGroupByVpcId(vpcId string) (*[]SecurityGroup, error)
- func (c *Client) ListSubnets(args *ListSubnetsArgs) (*ListSubnetsResult, error)
- func (c *Client) ListVpc() (*[]VpcVo, error)
- func (c *Client) ModifyBackupPolicy(instanceId string, args *BackupPolicy) error
- func (c *Client) ModifySyncMode(instanceId string, args *ModifySyncModeArgs) error
- func (c *Client) ReBalanceRoGroup(roGroupId string) error
- func (c *Client) RebootInstance(instanceId string, args *RebootArgs) error
- func (c *Client) RecoverRecyclerInstances(instanceIds []string) error
- func (c *Client) ReplaceSecurityGroups(args *SecurityGroupArgs) error
- func (c *Client) ResizeRds(instanceId string, args *ResizeRdsArgs) error
- func (c *Client) SnapshotAccessDetail(args *AccessDetailArgs) (*BackupAccessDetail, error)
- func (c *Client) SupplyVpcInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
- func (c *Client) SupplyZoneAndSubnetInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
- func (c *Client) SwitchInstance(instanceId string, args *SwitchArgs) error
- func (c *Client) UnBindSecurityGroups(args *SecurityGroupArgs) error
- func (c *Client) UnDefaultVpcInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
- func (c *Client) UpdateAccountDesc(instanceId string, accountName string, args *UpdateAccountDescArgs) error
- func (c *Client) UpdateAccountPassword(instanceId string, accountName string, args *UpdateAccountPasswordArgs) error
- func (c *Client) UpdateAccountPrivileges(instanceId string, accountName string, args *UpdateAccountPrivilegesArgs) error
- func (c *Client) UpdateDatabaseRemark(instanceId string, dbName string, args *UpdateDatabaseRemarkArgs) error
- func (c *Client) UpdateDeploySet(poolId string, deployId string, args *UpdateDeployRequest) error
- func (c *Client) UpdateInstanceName(instanceId string, args *UpdateInstanceNameArgs) error
- func (c *Client) UpdateMaintainTime(instanceId string, args *MaintainTime) error
- func (c *Client) UpdateParameter(instanceId string, args *UpdateParameterArgs) error
- func (c *Client) UpdateRoGroup(roGroupId string, args *UpdateRoGroupArgs) error
- func (c *Client) UpdateRoGroupReplicaWeight(roGroupId string, args *UpdateRoGroupWeightArgs) error
- func (c *Client) UpdateSecurityIps(instacneId string, args *UpdateSecurityIpsArgs) error
- type Container
- type CreateAccountArgs
- type CreateDatabaseArgs
- type CreateDeployRequest
- type CreateInstance
- type CreateInstanceArgs
- type CreateRdsArgs
- type CreateReadReplicaArgs
- type CreateResult
- type CreateTableHardLinkArgs
- type Database
- type DatabasePrivilege
- type DatabaseResult
- type DeleteDdcArgs
- type DeploySet
- type Disk
- type Endpoint
- type Flavor
- type GetBackupListArgs
- type GetBackupListResult
- type GetLogArgs
- type GetSecurityIpsResult
- type GetZoneListResult
- type Host
- type Instance
- type InstanceModel
- type InstanceModelResult
- type KVParameter
- type ListAccountResult
- type ListDatabaseResult
- type ListDeploySetResult
- type ListHostResult
- type ListLogArgs
- type ListParametersResult
- type ListPoolResult
- type ListRdsArgs
- type ListRdsResult
- type ListResultWithMarker
- type ListRoGroupResult
- type ListSecurityGroupResult
- type ListSubnetsArgs
- type ListSubnetsResult
- type Log
- type LogDetail
- type MaintainTime
- type MaintainWindow
- type Marker
- type ModifySyncModeArgs
- type NodeInfo
- type OperateHostRequest
- type Pagination
- type Parameter
- type Pool
- type RebootArgs
- type RecycleInstance
- type RecyclerInstanceList
- type Replica
- type ReplicaWeight
- type Reservation
- type ResizeRdsArgs
- type RoGroup
- type SecurityGroup
- type SecurityGroupArgs
- type SecurityGroupDetail
- type SecurityGroupRule
- type SecurityIpsRawResult
- type Snapshot
- type SnapshotModel
- type Subnet
- type SubnetMap
- type SubnetVo
- type SwitchArgs
- type Topology
- type UpdateAccountDescArgs
- type UpdateAccountPasswordArgs
- type UpdateAccountPrivilegesArgs
- type UpdateDatabaseRemarkArgs
- type UpdateDeployRequest
- type UpdateInstanceNameArgs
- type UpdateParameterArgs
- type UpdateRoGroupArgs
- type UpdateRoGroupWeightArgs
- type UpdateSecurityIpsArgs
- type VpcVo
- type ZoneName
Constants ¶
const ( URI_PREFIX = bce.URI_PREFIX + "v1/ddc" DEFAULT_ENDPOINT = "ddc.su.baidubce.com" REQUEST_DDC_INSTANCE_URL = "/instance" REQUEST_DDC_POOL_URL = "/pool" REQUEST_DDC_HOST_URL = "/host" REQUEST_DDC_DEPLOY_URL = "/deploy" REQUEST_DDC_DATABASE_URL = "/database" REQUEST_DDC_TABLE_URL = "/table" REQUEST_DDC_HARDLINK_URL = "/link" REQUEST_DDC_ACCOUNT_URL = "/account" REQUEST_DDC_ROGROUP_URL = "/roGroup" REQUEST_DDC_RECYCLER_URL = "/recycler" REQUEST_DDC_SECURITYGROUP_URL = "/security" REQUEST_DDC_LOG_URL = "/logs" REQUEST_DDC_UPDATE_ACTION = "/update" REQUEST_DDC_MAINTAINTIME_URL = "/maintenTimeInfo" REQUEST_UPDATE_MAINTAINTIME_URL = "/updateMaintenTime" )
const ( KEY_CLIENT_TOKEN = "clientToken" KEY_MARKER = "marker" KEY_MAX_KEYS = "maxKeys" COMMA = "," )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessDetailArgs ¶ added in v0.9.143
type AccessDetailItem ¶ added in v0.9.143
type AccessDetailItem struct {
BackupID string `json:"backupID"`
AccessDateTime string `json:"accessDateTime"`
AccessResult string `json:"accessResult"`
AccessSrcAddressType string `json:"accessSrcAddressType"`
AvailableZone string `json:"availableZone"`
AccessSrcAddress string `json:"accessSrcAddress"`
AccessOperationType string `json:"accessOperationType"`
StorageType string `json:"storageType"`
StorageAddress string `json:"storageAddress"`
Region string `json:"region"`
BackupName string `json:"backupName"`
AccessSrcAgent string `json:"accessSrcAgent"`
StorageID string `json:"storageID"`
}
type Account ¶
type Account struct {
AccountName string `json:"accountName"`
Desc string `json:"remark"`
Status string `json:"accountStatus"`
AccountType string `json:"accountType"`
DatabasePrivileges []DatabasePrivilege `json:"databasePrivileges"`
}
type AccountPrivilege ¶
type AccountResult ¶
type AccountResult struct {
Account Account `json:"account"`
}
type AccountType ¶
type AccountType string
Account
const ( AccountType_Super AccountType = "rdssuper" AccountType_Common AccountType = "common" )
type BackupAccessDetail ¶ added in v0.9.143
type BackupAccessDetail struct {
StartDateTime string `json:"startDateTime"`
EndDateTime string `json:"endDateTime"`
DataType string `json:"dataType"`
BackupAccessDetails []AccessDetailItem `json:"backupAccessDetails"`
Pagination Pagination `json:"pagination"`
}
type BackupDetailResult ¶
type BackupDetailResult struct {
Snapshot SnapshotModel `json:"snapshot"`
}
type BackupPolicy ¶
type BatchInstanceIds ¶ added in v0.9.48
type BatchInstanceIds struct {
InstanceIds string `json:"instanceIds"`
}
type Billing ¶ added in v0.9.42
type Billing struct {
PaymentTiming string `json:"paymentTiming"`
Reservation Reservation `json:"reservation,omitempty"`
}
type BinlogDetailResult ¶
type BinlogDetailResult struct {
Binlog BinlogModel `json:"binlog"`
}
type BinlogListResult ¶
type BinlogListResult struct {
Binlogs []Binlog `json:"binlogs"`
}
type BinlogModel ¶
type BinlogModel struct {
BinlogId string `json:"binlogId"`
BinlogSizeInBytes int64 `json:"binlogSizeInBytes"`
BinlogStatus string `json:"binlogStatus"`
BinlogStartTime string `json:"binlogStartTime"`
BinlogEndTime string `json:"binlogEndTime"`
DownloadUrl string `json:"downloadUrl"`
DownloadExpires string `json:"downloadExpires"`
}
type Client ¶
Client of DDC service is a kind of BceClient, so derived from BceClient
func (*Client) BindSecurityGroups ¶ added in v0.9.48
func (c *Client) BindSecurityGroups(args *SecurityGroupArgs) error
BindSecurityGroups - bind SecurityGroup to instances
PARAMS:
- args: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) BinlogAccessDetail ¶ added in v0.9.143
func (c *Client) BinlogAccessDetail(args *AccessDetailArgs) (*BackupAccessDetail, error)
BinlogAccessDetail - get snapshot access detail
PARAMS:
- args: the arguments to get snapshot access detail
RETURNS:
- *AccessDetail
- error: nil if success otherwise the specific error
func (*Client) CreateAccount ¶
func (c *Client) CreateAccount(instanceId string, args *CreateAccountArgs) error
CreateAccount - create a account with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- args: the arguments to create a account
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) CreateBackup ¶
CreateBackup - create backup of the instance
PARAMS:
- instanceId: the id of the instance
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) CreateDatabase ¶
func (c *Client) CreateDatabase(instanceId string, args *CreateDatabaseArgs) error
CreateDatabase - create a database with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- args: the arguments to create a account
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) CreateDeploySet ¶
func (cli *Client) CreateDeploySet(poolId string, args *CreateDeployRequest) error
CreateDeploySet - create a deploy set
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) CreateInstance ¶
func (c *Client) CreateInstance(args *CreateInstanceArgs) (*CreateResult, error)
CreateInstance - create a Instance with the specific parameters
PARAMS:
- args: the arguments to create a instance
RETURNS:
- *InstanceIds: the result of create RDS, contains new RDS's instanceIds
- error: nil if success otherwise the specific error
func (*Client) CreateRds ¶ added in v0.9.42
func (c *Client) CreateRds(args *CreateRdsArgs) (*CreateResult, error)
CreateRds - create a DDC with the specific parameters
PARAMS:
- args: the arguments to create a ddc
RETURNS:
- *InstanceIds: the result of create DDC, contains new DDC's instanceIds
- error: nil if success otherwise the specific error
func (*Client) CreateReadReplica ¶ added in v0.9.42
func (c *Client) CreateReadReplica(args *CreateReadReplicaArgs) (*CreateResult, error)
CreateReadReplica - create a readReplica ddc with the specific parameters
PARAMS:
- args: the arguments to create a readReplica ddc
RETURNS:
- *InstanceIds: the result of create a readReplica ddc, contains the readReplica DDC's instanceIds
- error: nil if success otherwise the specific error
func (*Client) DeleteAccount ¶
DeleteAccount - delete an account of a RDS instance
PARAMS:
- instanceIds: the specific instanceIds
- accountName: the specific account's name
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) DeleteDatabase ¶
DeleteDatabase - delete an database of a DDC instance
PARAMS:
- instanceIds: the specific instanceIds
- dbName: the specific database's name
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) DeleteDeploySet ¶
DeleteDeploySet - delete a deploy set
PARAMS:
- poolId: the id of the pool
- deploySetId: the id of the deploy set
- clientToken: idempotent token, an ASCII string no longer than 64 bits
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) DeleteRds ¶ added in v0.9.42
DeleteRds - delete instances
PARAMS:
- instanceIds: id of the instance
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) DeleteRecyclerInstances ¶ added in v0.9.48
DeleteRecyclerInstances - batch delete instances that in recycler
PARAMS:
- instanceIds: instanceId list to delete
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) GetAccount ¶
GetAccount - get an account of a DDC instance with the specific parameters
PARAMS:
- instanceId: the specific rds Instance's ID
- accountName: the specific account's name
RETURNS:
- *Account: the account's meta
- error: nil if success otherwise the specific error
func (*Client) GetBackupDetail ¶
func (c *Client) GetBackupDetail(instanceId string, snapshotId string) (*BackupDetailResult, error)
GetBackupDetail - get details of the instance'Backup
PARAMS:
- instanceId: the id of the instance
- snapshotId: the id of the backup
RETURNS:
- *BackupDetailResult: the detail of the backup
- error: nil if success otherwise the specific error
func (*Client) GetBackupList ¶
func (c *Client) GetBackupList(instanceId string) (*GetBackupListResult, error)
GetBackupList - get backup list of the instance
PARAMS:
- instanceId: id of the instance
RETURNS:
- *GetBackupListResult: result of the backup list
- error: nil if success otherwise the specific error
func (*Client) GetBinlogDetail ¶
func (c *Client) GetBinlogDetail(instanceId string, binlog string) (*BinlogDetailResult, error)
GetBinlogDetail - get details of the instance'Binlog
PARAMS:
- instanceId: the id of the instance
- binlog: the id of the binlog
RETURNS:
- *BinlogDetailResult: the detail of the binlog
- error: nil if success otherwise the specific error
func (*Client) GetBinlogList ¶
func (c *Client) GetBinlogList(instanceId string, datetime string) (*BinlogListResult, error)
GetBinlogList - get backup list of the instance
PARAMS:
- instanceId: id of the instance
RETURNS:
- *BinlogListResult: result of the backup list
- error: nil if success otherwise the specific error
func (*Client) GetDatabase ¶
GetDatabase - get an database of a DDC instance with the specific parameters
PARAMS:
- instanceId: the specific rds Instance's ID
- dbName: the specific database's name
RETURNS:
- *Database: the database's meta
- error: nil if success otherwise the specific error
func (*Client) GetDdcDetail ¶ added in v0.9.42
func (c *Client) GetDdcDetail(instanceId string) (*InstanceModelResult, error)
GetDdcDetail - get details of the instance
PARAMS:
- instanceId: the id of the instance
RETURNS:
- *InstanceModelResult: the detail of the instance
- error: nil if success otherwise the specific error
func (*Client) GetDeploySet ¶
GetDeploySet - get details of the deploy set
PARAMS:
- poolId: the id of the pool
- cli: the client agent which can perform sending request
- deploySetId: the id of the deploy set
RETURNS:
- *DeploySet: the detail of the deploy set
- error: nil if success otherwise the specific error
func (*Client) GetDetail ¶
GetDetail - get a specific ddc Instance's detail
PARAMS:
- instanceId: the specific ddc Instance's ID
RETURNS:
- *Instance: the specific ddc Instance's detail
- error: nil if success otherwise the specific error
func (*Client) GetDisk ¶ added in v0.9.57
GetDisk - get disk detail of instance
PARAMS:
- instanceId: id of instance
RETURNS:
- *Disk:disk of instance
- error: nil if success otherwise the specific error
func (*Client) GetLogById ¶ added in v0.9.50
func (c *Client) GetLogById(instanceId, logId string, args *GetLogArgs) (*LogDetail, error)
GetLogById - get log's detail of instance
PARAMS:
- instanceId: id of instance
RETURNS:
- *Log:log's detail of instance
- error: nil if success otherwise the specific error
func (*Client) GetMaintainTime ¶ added in v0.9.45
func (c *Client) GetMaintainTime(instanceId string) (*MaintainTime, error)
GetMaintenTime - get details of the maintenTime
PARAMS:
- poolId: the id of the pool
- cli: the client agent which can perform sending request
- deploySetId: the id of the deploy set
RETURNS:
- *DeploySet: the detail of the deploy set
- error: nil if success otherwise the specific error
func (*Client) GetSecurityIps ¶
func (c *Client) GetSecurityIps(instanceId string) (*GetSecurityIpsResult, error)
GetSecurityIps - get all SecurityIps
PARAMS:
- instanceId: the specific rds Instance's ID
RETURNS:
- *GetSecurityIpsResult: all security IP
- error: nil if success otherwise the specific error
func (*Client) GetZoneList ¶
func (c *Client) GetZoneList() (*GetZoneListResult, error)
GetZoneList - list all zone
PARAMS:
- c: the client agent which can perform sending request
RETURNS:
- *GetZoneListResult: result of the zone list
- error: nil if success otherwise the specific error
func (*Client) LazyDropCreateHardLink ¶ added in v0.9.50
LazyDropCreateHardLink - create a hard link for specified large table
PARAMS:
- instanceId: id of instance
- dbName: name of database
- tableName: name of table
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) LazyDropDeleteHardLink ¶ added in v0.9.50
LazyDropDeleteHardLink - delete the hard link for specified large table
PARAMS:
- instanceId: id of instance
- dbName: name of database
- tableName: name of table
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) ListAccount ¶
func (c *Client) ListAccount(instanceId string) (*ListAccountResult, error)
ListAccount - list all account of a DDC instance with the specific parameters
PARAMS:
- instanceId: the specific rds Instance's ID
RETURNS:
- *ListAccountResult: the result of list all account, contains all accounts' meta
- error: nil if success otherwise the specific error
func (*Client) ListDatabase ¶
func (c *Client) ListDatabase(instanceId string) (*ListDatabaseResult, error)
ListDatabase - list all database of a DDC instance with the specific parameters
PARAMS:
- instanceId: the specific ddc Instance's ID
RETURNS:
- *ListDatabaseResult: the result of list all database, contains all databases' meta
- error: nil if success otherwise the specific error
func (*Client) ListDeploySets ¶
func (cli *Client) ListDeploySets(poolId string, marker *Marker) (*ListDeploySetResult, error)
ListDeploySets - list all deploy sets RETURNS:
- *ListResultWithMarker: the result of list deploy sets with marker
- error: nil if success otherwise the specific error
func (*Client) ListLogByInstanceId ¶ added in v0.9.50
func (c *Client) ListLogByInstanceId(instanceId string, args *ListLogArgs) (*[]Log, error)
ListLogByInstanceId - list error or slow logs of instance
PARAMS:
- instanceId: id of instance
RETURNS:
- *[]Log:logs of instance
- error: nil if success otherwise the specific error
func (*Client) ListParameters ¶
func (c *Client) ListParameters(instanceId string) (*ListParametersResult, error)
ListParameters - list all parameters of a RDS instance
PARAMS:
- instanceId: the specific rds Instance's ID
RETURNS:
- *ListParametersResult: the result of list all parameters
- error: nil if success otherwise the specific error
func (*Client) ListPool ¶ added in v0.9.53
func (cli *Client) ListPool(marker *Marker) (*ListPoolResult, error)
ListPool - list current pools RETURNS:
- *ListResultWithMarker: the result of list hosts with marker
- error: nil if success otherwise the specific error
func (*Client) ListRds ¶ added in v0.9.42
func (c *Client) ListRds(marker *ListRdsArgs) (*ListRdsResult, error)
ListRds - list all instances RETURNS:
- *ListRdsResult: the result of list instances with marker
- error: nil if success otherwise the specific error
func (*Client) ListRecycleInstances ¶ added in v0.9.48
func (c *Client) ListRecycleInstances(marker *Marker) (*RecyclerInstanceList, error)
ListRecycleInstances - list all instances in recycler with marker
PARAMS:
- marker: marker page
RETURNS:
- *RecyclerInstanceList: the result of instances in recycler
- error: nil if success otherwise the specific error
func (*Client) ListRoGroup ¶
func (c *Client) ListRoGroup(instanceId string) (*ListRoGroupResult, error)
ListRoGroup - list all roGroups of a DDC instance with the specific parameters
PARAMS:
- instanceId: the specific rds Instance's ID
RETURNS:
- *ListRoGroupResult: All roGroups of the current instance
- error: nil if success otherwise the specific error
func (*Client) ListSecurityGroupByInstanceId ¶ added in v0.9.48
func (c *Client) ListSecurityGroupByInstanceId(instanceId string) (*ListSecurityGroupResult, error)
ListSecurityGroupByInstanceId - list security groups by instance id
PARAMS:
- instanceId: id of instance
RETURNS:
- *ListSecurityGroupResult: list secrity groups result of instance
- error: nil if success otherwise the specific error
func (*Client) ListSecurityGroupByVpcId ¶ added in v0.9.48
func (c *Client) ListSecurityGroupByVpcId(vpcId string) (*[]SecurityGroup, error)
ListSecurityGroupByVpcId - list security groups by vpc id
PARAMS:
- vpcId: id of vpc
RETURNS:
- *[]SecurityGroup:security groups of vpc
- error: nil if success otherwise the specific error
func (*Client) ListSubnets ¶
func (c *Client) ListSubnets(args *ListSubnetsArgs) (*ListSubnetsResult, error)
ListsSubnet - list all Subnets
PARAMS:
- c: the client agent which can perform sending request
- args: the arguments to list all subnets, not necessary
RETURNS:
- *ListSubnetsResult: result of the subnet list
- error: nil if success otherwise the specific error
func (*Client) ListVpc ¶
ListVpc - list all Vpc
PARAMS: RETURNS:
- *ListVpc: All vpc of
- error: nil if success otherwise the specific error
func (*Client) ModifyBackupPolicy ¶
func (c *Client) ModifyBackupPolicy(instanceId string, args *BackupPolicy) error
ModifyBackupPolicy - update backupPolicy
PARAMS:
- instanceId: the specific rds Instance's ID
- Args: the specific rds Instance's BackupPolicy
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) ModifySyncMode ¶ added in v0.9.55
func (c *Client) ModifySyncMode(instanceId string, args *ModifySyncModeArgs) error
UpdateSyncMode - update sync mode of a specified instance
PARAMS:
- cli: the client agent which can perform sending request
- instanceId: id of the instance
- args: the arguments to update syncMode
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) ReBalanceRoGroup ¶ added in v0.9.45
ReBalanceRoGroup- Initiate a rebalance for foGroup
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) RebootInstance ¶ added in v0.9.45
func (c *Client) RebootInstance(instanceId string, args *RebootArgs) error
RebootInstance - reboot a specified instance
PARAMS:
- cli: the client agent which can perform sending request
- instanceId: id of the instance to be rebooted
- args: reboot args
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) RecoverRecyclerInstances ¶ added in v0.9.48
RecoverRecyclerInstances - batch recover instances that in recycler
PARAMS:
- instanceIds: instanceId list to recover
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) ReplaceSecurityGroups ¶ added in v0.9.48
func (c *Client) ReplaceSecurityGroups(args *SecurityGroupArgs) error
ReplaceSecurityGroups - replace SecurityGroup to instances
PARAMS:
- args: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) ResizeRds ¶ added in v0.9.52
func (c *Client) ResizeRds(instanceId string, args *ResizeRdsArgs) error
ResizeRds - resize an RDS with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- args: the arguments to resize an RDS
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) SnapshotAccessDetail ¶ added in v0.9.143
func (c *Client) SnapshotAccessDetail(args *AccessDetailArgs) (*BackupAccessDetail, error)
SnapshotAccessDetail - get snapshot access detail
PARAMS:
- args: the arguments to get snapshot access detail
RETURNS:
- *AccessDetail
- error: nil if success otherwise the specific error
func (*Client) SupplyVpcInfo ¶ added in v0.9.42
func (c *Client) SupplyVpcInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
func (*Client) SupplyZoneAndSubnetInfo ¶ added in v0.9.42
func (c *Client) SupplyZoneAndSubnetInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
func (*Client) SwitchInstance ¶
func (c *Client) SwitchInstance(instanceId string, args *SwitchArgs) error
SwitchInstance - main standby switching of the instance
PARAMS:
- instanceId: the id of the instance
- args: switch now or wait to the maintain time
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UnBindSecurityGroups ¶ added in v0.9.48
func (c *Client) UnBindSecurityGroups(args *SecurityGroupArgs) error
UnBindSecurityGroups - unbind SecurityGroup to instances
PARAMS:
- args: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UnDefaultVpcInfo ¶ added in v0.9.42
func (c *Client) UnDefaultVpcInfo(newArgs *CreateInstanceArgs, args *CreateRdsArgs) (*CreateInstanceArgs, error)
func (*Client) UpdateAccountDesc ¶ added in v0.9.42
func (c *Client) UpdateAccountDesc(instanceId string, accountName string, args *UpdateAccountDescArgs) error
UpdateAccountDesc - update a account desc with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- accountName: the specific accountName
- args: the arguments to update a account remark
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateAccountPassword ¶
func (c *Client) UpdateAccountPassword(instanceId string, accountName string, args *UpdateAccountPasswordArgs) error
UpdateAccountPassword - update a account password with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- accountName: the specific accountName
- args: the arguments to update a account password
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateAccountPrivileges ¶
func (c *Client) UpdateAccountPrivileges(instanceId string, accountName string, args *UpdateAccountPrivilegesArgs) error
UpdateAccountPrivileges - update a account privileges with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- accountName: the specific accountName
- args: the arguments to update a account privileges
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateDatabaseRemark ¶
func (c *Client) UpdateDatabaseRemark(instanceId string, dbName string, args *UpdateDatabaseRemarkArgs) error
UpdateDatabaseRemark - update a database remark with the specific parameters
PARAMS:
- instanceId: the specific instanceId
- dbName: the specific accountName
- args: the arguments to update a database remark
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateDeploySet ¶ added in v0.9.45
func (c *Client) UpdateDeploySet(poolId string, deployId string, args *UpdateDeployRequest) error
UpdateDeploySet - update a deploy set
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateInstanceName ¶
func (c *Client) UpdateInstanceName(instanceId string, args *UpdateInstanceNameArgs) error
UpdateInstanceName - update name of a specified instance
PARAMS:
- instanceId: id of the instance
- args: the arguments to update instanceName
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateMaintainTime ¶ added in v0.9.45
func (c *Client) UpdateMaintainTime(instanceId string, args *MaintainTime) error
UpdateMaintenTime - update UpdateMaintenTime of instance
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateParameter ¶
func (c *Client) UpdateParameter(instanceId string, args *UpdateParameterArgs) error
UpdateParameter - update Parameter
PARAMS:
- instanceId: the specific rds Instance's ID
- Args: *UpdateParameterArgs
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateRoGroup ¶ added in v0.9.45
func (c *Client) UpdateRoGroup(roGroupId string, args *UpdateRoGroupArgs) error
UpdateRoGroup - update a roGroup
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateRoGroupReplicaWeight ¶ added in v0.9.45
func (c *Client) UpdateRoGroupReplicaWeight(roGroupId string, args *UpdateRoGroupWeightArgs) error
UpdateRoGroupReplicaWeight- update repica weight in roGroup
PARAMS:
- body: http request body
RETURNS:
- error: nil if success otherwise the specific error
func (*Client) UpdateSecurityIps ¶
func (c *Client) UpdateSecurityIps(instacneId string, args *UpdateSecurityIpsArgs) error
UpdateSecurityIps - update SecurityIps
PARAMS:
- instanceId: the specific rds Instance's ID
- Args: all SecurityIps
RETURNS:
- error: nil if success otherwise the specific error
type Container ¶
type Container struct {
ContainerID string `json:"containerId"`
DeployID string `json:"deployId"`
DeployName string `json:"deployName"`
Engine string `json:"engine"`
HostID string `json:"hostId"`
HostName string `json:"hostName"`
PoolName string `json:"poolName"`
Role string `json:"role"`
Zone string `json:"zone"`
}
type CreateAccountArgs ¶
type CreateAccountArgs struct {
ClientToken string `json:"-"`
AccountName string `json:"accountName"`
Password string `json:"password"`
// 为了兼容 RDS 参数结构
AccountType AccountType `json:"type"`
Desc string `json:"remark"`
DatabasePrivileges []DatabasePrivilege `json:"databasePrivileges,omitempty"`
}
type CreateDatabaseArgs ¶
type CreateDeployRequest ¶
type CreateInstance ¶ added in v0.9.42
type CreateInstance struct {
InstanceId string `json:"instanceId"`
InstanceName string `json:"instanceName"`
SourceInstanceId string `json:"sourceInstanceId"`
Engine string `json:"engine"`
EngineVersion string `json:"engineVersion"`
CpuCount int `json:"cpuCount"`
AllocatedMemoryInGB int `json:"allocatedMemoryInGB"`
AllocatedStorageInGB int `json:"allocatedStorageInGB"`
AZone string `json:"azone"`
VpcId string `json:"vpcId"`
SubnetId string `json:"subnetId"`
DiskIoType string `json:"diskIoType"`
DeployId string `json:"deployId"`
PoolId string `json:"poolId"`
RoGroupId string `json:"roGroupId"`
EnableDelayOff bool `json:"enableDelayOff"`
DelayThreshold int `json:"delayThreshold"`
LeastInstanceAmount int `json:"leastInstanceAmount"`
RoGroupWeight int `json:"roGroupWeight"`
IsDirectPay bool `json:"IsDirectPay"`
Billing Billing `json:"billing"`
AutoRenewTimeUnit string `json:"autoRenewTimeUnit,omitempty"`
AutoRenewTime int `json:"autoRenewTime,omitempty"`
Category string `json:"category,omitempty"`
Tags []model.TagModel `json:"tags,omitempty"`
SyncMode string `json:"syncMode"`
}
type CreateInstanceArgs ¶
type CreateInstanceArgs struct {
ClientToken string `json:"-"`
InstanceType string `json:"instanceType"`
Number int `json:"number"`
Instance CreateInstance `json:"instance"`
}
type CreateRdsArgs ¶ added in v0.9.42
type CreateRdsArgs struct {
ClientToken string `json:"-"`
Billing Billing `json:"billing"`
PurchaseCount int `json:"purchaseCount,omitempty"`
InstanceName string `json:"instanceName,omitempty"`
Engine string `json:"engine"`
EngineVersion string `json:"engineVersion"`
Category string `json:"category,omitempty"`
CpuCount int `json:"cpuCount"`
MemoryCapacity int `json:"memoryCapacity"`
VolumeCapacity int `json:"volumeCapacity"`
ZoneNames []string `json:"zoneNames,omitempty"`
VpcId string `json:"vpcId,omitempty"`
IsDirectPay bool `json:"isDirectPay,omitempty"`
Subnets []SubnetMap `json:"subnets,omitempty"`
Tags []model.TagModel `json:"tags,omitempty"`
AutoRenewTimeUnit string `json:"autoRenewTimeUnit,omitempty"`
AutoRenewTime int `json:"autoRenewTime,omitempty"`
DeployId string `json:"deployId"`
PoolId string `json:"poolId"`
SyncMode string `json:"syncMode"`
}
type CreateReadReplicaArgs ¶ added in v0.9.42
type CreateReadReplicaArgs struct {
ClientToken string `json:"-"`
Billing Billing `json:"billing"`
PurchaseCount int `json:"purchaseCount,omitempty"`
SourceInstanceId string `json:"sourceInstanceId"`
InstanceName string `json:"instanceName,omitempty"`
CpuCount int `json:"cpuCount"`
MemoryCapacity int `json:"memoryCapacity"`
VolumeCapacity int `json:"volumeCapacity"`
ZoneNames []string `json:"zoneNames,omitempty"`
VpcId string `json:"vpcId,omitempty"`
IsDirectPay bool `json:"isDirectPay,omitempty"`
Subnets []SubnetMap `json:"subnets,omitempty"`
Tags []model.TagModel `json:"tags,omitempty"`
DeployId string `json:"deployId"`
PoolId string `json:"poolId"`
RoGroupId string `json:"roGroupId"`
EnableDelayOff bool `json:"enableDelayOff"`
DelayThreshold int `json:"delayThreshold"`
LeastInstanceAmount int `json:"leastInstanceAmount"`
RoGroupWeight int `json:"roGroupWeight"`
}
type CreateResult ¶
type CreateResult struct {
InstanceIds []string `json:"instanceIds"`
}
type CreateTableHardLinkArgs ¶ added in v0.9.50
type CreateTableHardLinkArgs struct {
TableName string `json:"tableName"`
}
type Database ¶
type Database struct {
DbName string `json:"dbName"`
CharacterSetName string `json:"characterSetName"`
DbStatus string `json:"dbStatus"`
Remark string `json:"remark"`
AccountPrivileges []AccountPrivilege `json:"accountPrivileges"`
}
type DatabasePrivilege ¶
type DatabaseResult ¶
type DatabaseResult struct {
Database Database `json:"database"`
}
type DeleteDdcArgs ¶
type DeleteDdcArgs struct {
InstanceIds []string `json:"instanceIds"`
}
type GetBackupListArgs ¶ added in v0.9.42
type GetBackupListResult ¶
type GetLogArgs ¶ added in v0.9.50
type GetLogArgs struct {
ValidSeconds int `json:"downloadValidTimeInSec"`
}
type GetSecurityIpsResult ¶
type GetZoneListResult ¶
type GetZoneListResult struct {
Zones []ZoneName `json:"zones"`
}
type Host ¶
type Host struct {
Containers []Container `json:"containers"`
Flavor Flavor `json:"flavor"`
CPUQuotaTotal int `json:"cpuQuotaTotal"`
CPUQuotaUsed int `json:"cpuQuotaUsed"`
DeploymentStatus string `json:"deploymentStatus"`
DiskQuotaTotal int `json:"diskQuotaTotal"`
DiskQuotaUsed int `json:"diskQuotaUsed"`
HostID string `json:"hostId"`
HostName string `json:"hostName"`
ImageType string `json:"imageType"`
MemoryQuotaTotal int64 `json:"memoryQuotaTotal"`
MemoryQuotaUsed int64 `json:"memoryQuotaUsed"`
PnetIP string `json:"pnetIp"`
Role string `json:"role"`
Status string `json:"status"`
SubnetID string `json:"subnetId"`
VnetIP string `json:"vnetIp"`
VpcID string `json:"vpcId"`
Zone string `json:"zone"`
}
type Instance ¶
type Instance struct {
InstanceId string `json:"instanceId"`
InstanceName string `json:"instanceName"`
Engine string `json:"engine"`
EngineVersion string `json:"engineVersion"`
Category string `json:"category"`
InstanceStatus string `json:"instanceStatus"`
CpuCount int `json:"cpuCount"`
MemoryCapacity float64 `json:"allocatedMemoryInGB"`
VolumeCapacity int `json:"allocatedStorageInGB"`
NodeAmount int `json:"nodeAmount"`
UsedStorage float64 `json:"usedStorageInGB"`
PublicAccessStatus bool `json:"publicAccessStatus"`
InstanceCreateTime string `json:"instanceCreateTime"`
InstanceExpireTime string `json:"instanceExpireTime"`
Endpoint Endpoint `json:"endpoint"`
SyncMode string `json:"syncMode"`
BackupPolicy BackupPolicy `json:"backupPolicy"`
Region string `json:"region"`
InstanceType string `json:"type"`
SourceInstanceId string `json:"sourceInstanceId"`
SourceRegion string `json:"sourceRegion"`
ZoneNames []string `json:"zoneNames"`
VpcId string `json:"vpcId"`
Subnets []Subnet `json:"subnets"`
Topology Topology `json:"topology"`
PaymentTiming string `json:"paymentTiming"`
RoGroupList []RoGroup `json:"roGroupList"`
NodeMaster NodeInfo `json:"nodeMaster"`
NodeSlave NodeInfo `json:"nodeSlave"`
NodeReadReplica NodeInfo `json:"nodeReadReplica"`
DeployId string `json:"deployId"`
}
type InstanceModel ¶
type InstanceModel struct {
InstanceId string `json:"instanceId"`
InstanceName string `json:"instanceName"`
Engine string `json:"engine"`
EngineVersion string `json:"engineVersion"`
InstanceStatus string `json:"instanceStatus"`
CpuCount int `json:"cpuCount"`
AllocatedMemoryInGB float64 `json:"allocatedMemoryInGB"`
AllocatedStorageInGB int `json:"allocatedStorageInGB"`
NodeAmount int `json:"nodeAmount"`
UsedStorageInGB float64 `json:"usedStorageInGB"`
PublicAccessStatus bool `json:"publicAccessStatus"`
InstanceCreateTime string `json:"instanceCreateTime"`
InstanceExpireTime string `json:"instanceExpireTime"`
Endpoint Endpoint `json:"endpoint"`
SyncMode string `json:"syncMode"`
BackupPolicy BackupPolicy `json:"backupPolicy"`
Region string `json:"region"`
InstanceType string `json:"instanceType"`
SourceInstanceId string `json:"sourceInstanceId"`
SourceRegion string `json:"sourceRegion"`
ZoneNames []string `json:"zoneNames"`
VpcId string `json:"vpcId"`
Subnets []Subnet `json:"subnets"`
NodeMaster NodeInfo `json:"nodeMaster"`
NodeSlave NodeInfo `json:"nodeSlave"`
NodeReadReplica NodeInfo `json:"nodeReadReplica"`
DeployId string `json:"deployId"`
Topology Topology `json:"topology"`
DiskType string `json:"diskType"`
Type string `json:"type"`
ApplicationType string `json:"applicationType"`
RoGroupList []RoGroup `json:"roGroupList"`
PaymentTiming string `json:"paymentTiming"`
}
type InstanceModelResult ¶
type InstanceModelResult struct {
Instance InstanceModel `json:"instance"`
}
type KVParameter ¶
type ListAccountResult ¶
type ListAccountResult struct {
Accounts []Account `json:"accounts"`
}
type ListDatabaseResult ¶
type ListDatabaseResult struct {
Databases []Database `json:"databases"`
}
type ListDeploySetResult ¶
type ListDeploySetResult struct {
ListResultWithMarker
Result []DeploySet `json:"result"`
}
type ListHostResult ¶
type ListHostResult struct {
ListResultWithMarker
Result []Host `json:"result"`
}
type ListLogArgs ¶ added in v0.9.50
type ListParametersResult ¶
type ListParametersResult struct {
Items []Parameter `json:"items"`
}
type ListPoolResult ¶
type ListPoolResult struct {
ListResultWithMarker
Result []Pool `json:"result"`
}
type ListRdsArgs ¶
type ListRdsResult ¶ added in v0.9.42
type ListResultWithMarker ¶
type ListRoGroupResult ¶
type ListRoGroupResult struct {
RoGroups []RoGroup `json:"roGroups"`
}
type ListSecurityGroupResult ¶ added in v0.9.48
type ListSecurityGroupResult struct {
Groups []SecurityGroupDetail `json:"groups"`
}
type ListSubnetsArgs ¶
type ListSubnetsResult ¶
type ListSubnetsResult struct {
Subnets []Subnet `json:"subnets"`
}
type MaintainTime ¶ added in v0.9.46
type MaintainWindow ¶ added in v0.9.46
type MaintainWindow struct {
MaintainTime MaintainTime `json:"maintentime"`
}
type ModifySyncModeArgs ¶ added in v0.9.55
type ModifySyncModeArgs struct {
SyncMode string `json:"syncMode"`
}
type OperateHostRequest ¶
type OperateHostRequest struct {
Action string `json:"action"`
}
type Pagination ¶ added in v0.9.143
type Parameter ¶
type Parameter struct {
Name string `json:"name"`
DefaultValue string `json:"defaultValue"`
Value string `json:"value"`
PendingValue string `json:"pendingValue"`
Type string `json:"type"`
Dynamic bool `json:"dynamic"`
Modifiable bool `json:"modifiable"`
AllowedValues string `json:"allowedValues"`
Desc string `json:"desc"`
}
type Pool ¶
type Pool struct {
CPUQuotaTotal int `json:"cpuQuotaTotal"`
CPUQuotaUsed int `json:"cpuQuotaUsed"`
CreateTime string `json:"createTime"`
DeployMethod string `json:"deployMethod"`
DiskQuotaTotal int `json:"diskQuotaTotal"`
DiskQuotaUsed int `json:"diskQuotaUsed"`
Engine string `json:"engine"`
Hosts []Host `json:"hosts"`
MaxMemoryUsedRatio string `json:"maxMemoryUsedRatio"`
MemoryQuotaTotal int `json:"memoryQuotaTotal"`
MemoryQuotaUsed int `json:"memoryQuotaUsed"`
PoolID string `json:"poolId"`
PoolName string `json:"poolName"`
VpcID string `json:"vpcId"`
}
type RebootArgs ¶ added in v0.9.45
type RebootArgs struct {
IsRebootNow bool `json:"isRebootNow"`
}
type RecycleInstance ¶ added in v0.9.48
type RecycleInstance struct {
EngineVersion string `json:"engineVersion"`
VolumeCapacity int `json:"volumeCapacity"`
ApplicationType string `json:"applicationType"`
InstanceName string `json:"instanceName"`
PublicAccessStatus string `json:"publicAccessStatus"`
InstanceCreateTime string `json:"instanceCreateTime"`
InstanceType string `json:"instanceType"`
Type string `json:"type"`
InstanceStatus string `json:"instanceStatus"`
MemoryCapacity float64 `json:"memoryCapacity"`
InstanceId string `json:"instanceId"`
Engine string `json:"engine"`
VpcId string `json:"vpcId"`
PubliclyAccessible bool `json:"publiclyAccessible"`
InstanceExpireTime string `json:"instanceExpireTime"`
DiskType string `json:"diskType"`
Region string `json:"region"`
CpuCount int `json:"cpuCount"`
UsedStorage float64 `json:"usedStorage"`
}
type RecyclerInstanceList ¶ added in v0.9.48
type RecyclerInstanceList struct {
ListResultWithMarker
Result []RecycleInstance `json:"result"`
}
type ReplicaWeight ¶ added in v0.9.45
type Reservation ¶ added in v0.9.42
type ResizeRdsArgs ¶ added in v0.9.52
type RoGroup ¶
type RoGroup struct {
RoGroupID string `json:"roGroupId"`
RoGroupName string `json:"roGroupName"`
VnetIP string `json:"vnetIp"`
IsBalanceRoLoad int `json:"isBalanceRoLoad"`
EnableDelayOff int `json:"enableDelayOff"`
DelayThreshold int `json:"delayThreshold"`
LeastInstanceAmount int `json:"leastInstanceAmount"`
ReplicaList []Replica `json:"replicaList"`
}
type SecurityGroup ¶ added in v0.9.48
type SecurityGroup struct {
Name string `json:"name"`
SecurityGroupID string `json:"securityGroupId"`
Description string `json:"description"`
TenantID string `json:"tenantId"`
AssociateNum int `json:"associateNum"`
VpcID string `json:"vpcId"`
VpcShortID string `json:"vpcShortId"`
VpcName string `json:"vpcName"`
CreatedTime string `json:"createdTime"`
Version int `json:"version"`
DefaultSecurityGroup int `json:"defaultSecurityGroup"`
}
type SecurityGroupArgs ¶ added in v0.9.48
type SecurityGroupDetail ¶ added in v0.9.48
type SecurityGroupDetail struct {
SecurityGroupName string `json:"securityGroupName"`
SecurityGroupID string `json:"securityGroupId"`
SecurityGroupRemark string `json:"securityGroupRemark"`
Inbound []SecurityGroupRule `json:"inbound"`
Outbound []SecurityGroupRule `json:"outbound"`
VpcName string `json:"vpcName"`
VpcID string `json:"vpcId"`
ProjectID string `json:"projectId"`
}
type SecurityGroupRule ¶ added in v0.9.48
type SecurityGroupRule struct {
PortRange string `json:"portRange"`
Protocol string `json:"protocol"`
RemoteGroupID string `json:"remoteGroupId"`
RemoteIP string `json:"remoteIP"`
Ethertype string `json:"ethertype"`
TenantID string `json:"tenantId"`
Name string `json:"name"`
ID string `json:"id"`
SecurityGroupRuleID string `json:"securityGroupRuleId"`
Direction string `json:"direction"`
}
type SecurityIpsRawResult ¶ added in v0.9.42
type SecurityIpsRawResult struct {
SecurityIps []string `json:"ip"`
}
type Snapshot ¶
type Snapshot struct {
SnapshotId string `json:"snapshotId"`
SnapshotSizeInBytes string `json:"snapshotSizeInBytes"`
SnapshotType string `json:"snapshotType"`
SnapshotStatus string `json:"snapshotStatus"`
SnapshotStartTime string `json:"snapshotStartTime"`
SnapshotEndTime string `json:"snapshotEndTime"`
}
type SnapshotModel ¶
type SnapshotModel struct {
SnapshotId string `json:"snapshotId"`
SnapshotSizeInBytes string `json:"snapshotSizeInBytes"`
SnapshotType string `json:"snapshotType"`
SnapshotStatus string `json:"snapshotStatus"`
SnapshotStartTime string `json:"snapshotStartTime"`
SnapshotEndTime string `json:"snapshotEndTime"`
DownloadUrl string `json:"downloadUrl"`
DownloadExpires string `json:"downloadExpires"`
Progress string `json:"progress"`
}
type Subnet ¶
type Subnet struct {
Name string `json:"name"`
SubnetId string `json:"subnetId"`
ZoneName string `json:"zoneName"`
Cidr string `json:"cidr"`
ShortId string `json:"shortId"`
VpcId string `json:"vpcId"`
VpcShortId string `json:"vpcShortId"`
Az string `json:"az"`
CreatedTime string `json:"createdTime"`
UpdatedTime string `json:"updatedTime"`
}
type SwitchArgs ¶ added in v0.9.50
type SwitchArgs struct {
IsSwitchNow bool `json:"isSwitchNow"`
}
type UpdateAccountDescArgs ¶ added in v0.9.42
type UpdateAccountDescArgs struct {
Desc string `json:"remark"`
}
type UpdateAccountPasswordArgs ¶
type UpdateAccountPasswordArgs struct {
Password string `json:"password"`
}
type UpdateAccountPrivilegesArgs ¶
type UpdateAccountPrivilegesArgs struct {
DatabasePrivileges []DatabasePrivilege `json:"databasePrivileges"`
}
type UpdateDatabaseRemarkArgs ¶
type UpdateDatabaseRemarkArgs struct {
Remark string `json:"remark"`
}
type UpdateDeployRequest ¶ added in v0.9.45
type UpdateInstanceNameArgs ¶
type UpdateInstanceNameArgs struct {
InstanceName string `json:"instanceName"`
}
type UpdateParameterArgs ¶
type UpdateParameterArgs struct {
Parameters []KVParameter `json:"parameters"`
}
type UpdateRoGroupArgs ¶ added in v0.9.45
type UpdateRoGroupWeightArgs ¶ added in v0.9.45
type UpdateRoGroupWeightArgs struct {
IsBalanceRoLoad int `json:"isBalanceRoLoad"`
ReplicaList []ReplicaWeight `json:"replicaList"`
}
type UpdateSecurityIpsArgs ¶
type UpdateSecurityIpsArgs struct {
SecurityIps []string `json:"securityIps"`
}
type VpcVo ¶
type VpcVo struct {
VpcId string `json:"vpcId"`
ShortId string `json:"shortId"`
Name string `json:"name"`
Cidr string `json:"cidr"`
Status int `json:"status"`
CreateTime string `json:"createTime"`
Description string `json:"description"`
DefaultVpc bool `json:"defaultVpc"`
Ipv6Cidr string `json:"ipv6Cidr"`
AuxiliaryCidr []string `json:"auxiliaryCidr"`
Relay bool `json:"relay"`
}